% This function prices a European Down and Out Put option 
% 
% Written by:   Michael Wencis, 2008
% Package:      MATLAB 7.5.0 with Statistics Toolbox
% 
% Option Definition:
% This is an option which is cancelled if, during the option's lifetime,
% the underlying price falls below a preset level.  A cash rebate may be
% paid out if the option is knocked out before expiry.
% 
% Parameters:
% S:      spot rate
% K:      strike price
% b:      barrier
% rd:     domestic risk-free rate
% rf:     foreign risk-free rate
% sd:     volatility
% T:      time to maturity (actual/365)
% R:      rebate
% 
% function call: EuropeanDownAndOutPut(S,K,b,rd,rf,sd,T,R)

function price = EuropeanDownAndOutPut(S,K,b,rd,rf,sd,T,R)
Vb = b;
l = (rd - rf + .5*sd*sd)/(sd*sd);
a = (rd - rf - .5*sd*sd)/(sd*sd);
b = sqrt(((rd-rf+.5*sd*sd)^2) + 2*rd*sd*sd)/(sd*sd);
x = (log(S/K)+(rd-rf)*T + .5*sd*sd*T)/(sd*sqrt(T));
y = (log((Vb*Vb)/(K*S))+ (rd-rf)*T + .5*sd*sd*T)/(sd*sqrt(T));
y1 = (log(Vb/S)+ (rd-rf)*T + .5*sd*sd*T)/(sd*sqrt(T));
z = (log(Vb/S)/(sd*sqrt(T))) + b*(sd*sqrt(T));
x1 = (log(S/Vb)+(rd-rf)*T + .5*sd*sd*T)/(sd*sqrt(T));

xi = 1;
phi = -1;
f1 = phi*(S*exp(-rf*T)*normcdf(phi*x) - K*exp(-rd*T)*normcdf(phi*(x-sd*sqrt(T))));
f2 = phi*(S*exp(-rf*T)*normcdf(phi*x1) - K*exp(-rd*T)*normcdf(phi*(x1-sd*sqrt(T))));
f3 = phi*S*exp(-rf*T)*((Vb/S)^(2*l))*normcdf(xi*y)- phi*K*exp(-rd*T)*((Vb/S)^(2*(l-1)))*normcdf(xi*(y-sd*sqrt(T)));
f4 = phi*S*exp(-rf*T)*((Vb/S)^(2*l))*normcdf(xi*y1) - phi*K*exp(-rd*T)*((Vb/S)^(2*(l-1)))*normcdf(xi*(y1-sd*sqrt(T)));
f6 = R*(((Vb/S)^(a+b))*normcdf(xi*z) + ((Vb/S)^(a-b))*normcdf(xi*(z - 2*b*sd*sqrt(T))));

if(K >= Vb)
    price = f1 - f2 + f3 - f4 + f6;
else
    price = f6;
end
